<?php

/**
 * Data alter for invoice.deliverycases.updating event.
 *
 * Код в этом файле будет выполнен, когда интернет-сайт получит уведомление от
 * PayQR о необходимости предоставить покупателю способы доставки конкретного
 * заказа.
 * Это означает, что интернет-сайт на уровне кнопки PayQR активировал этап
 * выбора способа доставки покупателем, и сейчас покупатель дошел до этого
 * этапа.
 *
 * $Payqr->objectOrder содержит объект "Счет на оплату" (подробнее об объекте
 * "Счет на оплату" на https://payqr.ru/api/ecommerce#invoice_object)
 *
 * Ниже можно вызвать функции своей учетной системы, чтобы особым образом
 * отреагировать на уведомление от PayQR о событии
 * invoice.deliverycases.updating.
 *
 * Важно: на уведомление от PayQR о событии invoice.deliverycases.updating
 * нельзя реагировать как на уведомление о создании заказа, так как иногда оно
 * будет поступать не от покупателей, а от PayQR для тестирования доступности
 * функционала у конкретного интернет-сайта, т.е. оно никак не связано с
 * реальным формированием заказов. Также важно, что в ответ на
 * invoice.deliverycases.updating интернет-сайт может передать в PayQR только
 * содержимое параметра deliveryCases объекта "Счет на оплату". Передаваемый в
 * PayQR от интернет-сайта список способов доставки может быть многоуровневым.
 *
 * Пример массива способов доставки:
 * $delivery_cases = array(
 *          array(
 *              'article' => '2001',
 *               'number' => '1.1',
 *               'name' => 'DHL',
 *               'description' => '1-2 дня',
 *               'amountFrom' => '0',
 *               'amountTo' => '70',
 *              ),
 *          .....
 *  );
 *
 * @param $order - temporrary commerce_order object to calculate shipping
 *   services, DO NOT SAVE IT into database to prevent order numberring
 *   through a single.
 * @param $delivery_cases - deliverycases array, it will be send to payqr.
 */
function HOOK_payqr_invoice_deliverycases_updating_alter(&$order, &$delivery_cases) {

}

/**
 * Data alter for invoice.pickpoints.updating event.
 *
 * Код в этом файле будет выполнен, когда интернет-сайт получит уведомление от
 * PayQR о необходимости предоставить покупателю пункты самовывоза конкретного
 * заказа.
 * Это означает, что интернет-сайт на уровне кнопки PayQR активировал этап
 * выбора пункта самовывоза покупателем, и сейчас покупатель дошел до этого
 * этапа.
 *
 * $Payqr->objectOrder содержит объект "Счет на оплату" (подробнее об объекте
 * "Счет на оплату" на https://payqr.ru/api/ecommerce#invoice_object)
 *
 * Ниже можно вызвать функции своей учетной системы, чтобы особым образом
 * отреагировать на уведомление от PayQR о событии invoice.pickpoints.updating.
 *
 * Важно: на уведомление от PayQR о событии invoice.pickpoints.updating нельзя
 * реагировать как на уведомление о создании заказа, так как иногда оно будет
 * поступать не от покупателей, а от PayQR для тестирования доступности
 * функционала у конкретного интернет-сайта, т.е. оно никак не связано с
 * реальным формированием заказов. Также важно, что в ответ на
 * invoice.pickpoints.updating интернет-сайт может передать в PayQR только
 * содержимое параметра pickPoints объекта "Счет на оплату". Передаваемый
 * в PayQR от интернет-сайта список пунктов самовывоза может быть
 * многоуровневым.
 *
 * Пример массива способов доставки:
 * $pick_points_cases = array(
 *          array(
 *              'article' => '1001',
 *               'number' => '1.1',
 *               'name' => 'Наш пункт самовывоза 1',
 *               'description' => 'с 10:00 до 22:00',
 *               'amountFrom' => '90',
 *               'amountTo' => '140',
 *              ),
 *          .....
 *  );
 * 
 * @param $order - temporrary commerce_order object to calculate shipping
 *   services, DO NOT SAVE IT into database to prevent order numberring
 *   through a single.
 * @param $delivery_cases - deliverycases array, it will be send to payqr.
 */
function HOOK_payqr_invoice_pickpoints_updating_alter(&$order, &$delivery_cases) {

}

