/**
 * Для быстрой интеграции с PayQR с помощью данной библиотеки достаточно:
 * 1. Распаковать архив данной библиотеки PayQR на хостинг своего интернет-сайта (желательно в отдельную папку payqr).
 * 2. Указать в личном кабинете PayQR в настройках своего "Магазина" в поле "URL для уведомлений" ссылку на файл payqr_receiver.php из состава библиотеки PayQR.
 * 3. Внести номер магазина (merchId) и секретные ключи (SecretKeyIn и SecretKeyOut) из личного кабинета PayQR в файл payqr_config.php из состава библиотеки PayQR.
 *
 * Этого хватит для того, чтобы совершение покупки в PayQR осуществлялось покупателем без ошибок. Дальше останется только прописать реакцию магазин на те или иные уведомления в файлах папки handlers из состава библиотеки PayQR.
 */


___
Чтобы вы смогли корректно учитывать данные о покупателях и покупках в учетной системе своего интернет-сайта, а также взаимодействовать с PayQR по обмену информацией, вам необходимо вставить свой код реализации логики обработки уведомлений от PayQR в соответствующие файлы из папки handlers.

Названия файлов соответствуют названиям событий, уведомления о которых PayQR будет направлять вашему интернет-сайту (посредством http/https-запросов по адресу, указанному в личном кабинете PayQR в поле "URL для уведомлений"). Подробнее об этих событиях в документации https://payqr.ru/api/ecommerce#event_types. Подробнее о том, как взаимодействовать с API PayQR по объектам "Счет на оплату" и "Возвраты" в комментариях в начале каждого из файлов в папке handlers.


___
Также ваш интернет-сайт может самостоятельно посылать определенные запросы в PayQR. Для этого используйте класс payqr_invoice_action.php для команд и функций по объектам "Счет на оплату" (подробнее https://payqr.ru/api/ecommerce#invoices) и класс payqr_revert_action.php для команд и функций по объектам "Возвраты" (подробнее https://payqr.ru/api/ecommerce#reverts).


___
Пример простейшего подключения PayQR к учетной системе интернет-сайта:

require_once 'payqr_config.php'; // подключаем основной класс

все дальнейшие операции желательно обернуть в try{}catch(payqr_exeption $e)
так как в случае ошибок при работе с API PayQR будут возникать исключения, отлавливая которые можно легко отследить причину любой проблемы

Основные переменные конфигурации содержатся в классе payqr_config.php

$Payqr = new payqr_receiver(); // создаем объект payqr_receiver
$idInvoce = $Payqr->receiving(); // метод получает тело POST-запроса и, в случае успешного разбора, вернет идентификатор счета на оплату (генерируется на стороне PayQR)

$Payqr->getType(); // этот метод вернет тип уведомления согласно https://payqr.ru/api/ecommerce#event_types

$Payqr->objectOrder->setOrderId($orderId); // устанавливаем в объекте "Счет на оплату" в PayQR номер заказа (orderId) из учетной системы своего интернет-сайта

$Payqr->response(); // отправляем ответ PayQR на уведомление от PayQR