/**
 * Библиотека для быстрой интеграции PayQR на интернет-сайты (PHP)
 * Версия библиотеки: 1.0
 * Помощь, вопросы и сообщения об ошибках: api@payqr.ru
 *
 * Рекомендуемые сферы применения: интернет-магазины, онлайн-сервисы, браузерные игры
 *
 * API PayQR и библиотека PayQR обладают большим количеством функций и возможностей, часть из которых нужна только небольшому количеству интернет-сайтов. Для ускорения и упрощения интеграции реализуйте у себя только то, что актуально для бизнес-логики конкретно вашего интернет-сайта, остальное игнорируйте и оставляйте "как есть" (оно по умолчанию работоспособно в библиотеке и уже корректно взаимодействует с API PayQR).
 */


___
Структура библиотеки:
payqr_config.php // файл конфигурации, подключает все необходимые файлы для работы
|- classes
  |- payqr_authentication.php // класс проверки валидности уведомлений и ответов от PayQR (проверки секретных ключей)
  |- payqr_autoload.php // класс автозагрузки классов библиотеки PayQR
  |- payqr_base.php // класс проверки конфигурации библиотеки PayQR
  |- payqr_base_request.php // класс реализации запросов в PayQR
  |- payqr_curl.php // класс обертки для cURL
  |- payqr_curl_response.php // класс обработки результатов запросов cURL
  |- payqr_exeption.php // класс исключения во время работы с API PayQR
  |- payqr_invoice.php // класс работы с объектами "Счет на оплату"
  |- payqr_invoice_action.php // класс методов по объектам "Счет на оплату"
  |- payqr_json_validator.php // класс JSON валидатора
  |- payqr_logs.php // класс ведения отладочных логов
  |- payqr_numeric_validator.php // класс валидатора чисел
  |- payqr_receiver.php // класс приема уведомлений от PayQR
  |- payqr_revert.php // класс работы с объектами "Возвраты"
  |- payqr_revert_action.php // класс методов по объектам "Возвраты"
|- example // примеры для ознакомления по принятию уведомлений от PayQR и направлению запросов в PayQR
  |- receiver.php // файл примера обработчика уведомлений от PayQR
  |- sender.php // файл примера работы с запросами в PayQR
  |- simple_receiver.php // файл примера обработчика уведомлений от PayQR (минимальная версия обработчика)
|- handlers // файлы обработчиков для уведомлений от PayQR о событиях в PayQR
|- handlers_errors // файлы обработчиков ошибок
  |- invoice_action_error.php // файл обработки ошибок по запросам в PayQR по объектам "Счет на оплату"
  |- revert_action_error.php // файл обработки ошибок по запросам в PayQR по объектам "Возвраты"
  |- reciver_error.php // файл обработки ошибок во время получения уведомлений от PayQR
|-payqr_receiver.php // основной файл, принимающий уведомления от PayQR (абсолютная ссылка на него указывается в личном кабинете PayQR в поле "URL для уведомлений")


___
Для быстрой интеграции с PayQR достаточно:
1. Распаковать данный архив на хостинг своего интернет-сайта (желательно в отдельную папку payqr)
2. Указать в личном кабинете PayQR в настройках своего "Магазина" в поле "URL для уведомлений" ссылку на файл payqr_receiver.php
3. Внести номер магазина (merchId) и секретные ключи из личного кабинета в файл payqr_config.php

Этого будет достаточно для того, чтобы совершение покупки в PayQR осуществлялось покупателем без ошибок.


___
Чтобы вы смогли корректно учитывать данные о покупателях и покупках в учетной системе своего интернет-сайта, а также взаимодействовать с PayQR по обмену информацией, вам необходимо вставить свой код реализации логики обработки уведомлений от PayQR в соответствующие файлы из папки handlers.

Названия файлов соответствуют названиям событий, уведомления о которых PayQR будет направлять вашему интернет-сайту (посредством http/https-запросов по адресу, указанному в личном кабинете PayQR в поле "URL для уведомлений"). Подробнее об этих событиях в документации https://payqr.ru/api/ecommerce#event_types. Подробнее о том, как взаимодействовать с API PayQR по объектам "Счет на оплату" и "Возвраты" в комментариях в начале каждого из файлов в папке handlers.


___
Также ваш интернет-сайт может самостоятельно посылать определенные запросы в PayQR. Для этого используйте класс payqr_invoice_action.php для команд и функций по объектам "Счет на оплату" (подробнее https://payqr.ru/api/ecommerce#invoices) и класс payqr_revert_action.php для команд и функций по объектам "Возвраты" (подробнее https://payqr.ru/api/ecommerce#reverts).


___
Пример простейшего подключения PayQR к учетной системе интернет-сайта:

require_once 'payqr_config.php'; // подключаем основной класс

все дальнейшие операции желательно обернуть в try{}catch(payqr_exeption $e)
так как в случае ошибок при работе с API PayQR будут возникать исключения, отлавливая которые можно легко отследить причину любой проблемы

Основные переменные конфигурации содержатся в классе payqr_config.php

$Payqr = new payqr_receiver(); // создаем объект payqr_receiver
$idInvoce = $Payqr->receiving(); // метод получает тело POST-запроса и, в случае успешного разбора, вернет идентификатор счета на оплату (генерируется на стороне PayQR)

$Payqr->getType(); // этот метод вернет тип уведомления согласно https://payqr.ru/api/ecommerce#event_types

$Payqr->objectOrder->setOrderId($orderId); // устанавливаем в объекте "Счет на оплату" в PayQR номер заказа (orderId) из учетной системы своего интернет-сайта

$Payqr->response(); // отправляем ответ PayQR на уведомление от PayQR



/**
 * Справочник API PayQR: https://payqr.ru/api/ecommerce
 * Документация по API PayQR: https://payqr.ru/api/doc
 * Ответы на частые вопросы: https://payqr.ru/api/faq
 * 
 * API PayQR использует архитектуру REST (https://en.wikipedia.org/wiki/Representational_state_transfer).
 * API PayQR поддерживает CORS (https://en.wikipedia.org/wiki/Cross-origin_resource_sharing) для безопасного взаимодействия с приложениями на клиентской стороне.
 * Данные в рамках API PayQR направляются в формате JSON (https://en.wikipedia.org/wiki/JSON).
 * Уведомления о событиях от PayQR поступают в интернет-сайт обычными http-/https-запросами (https://en.wikipedia.org/wiki/Webhook).
 * Обновления API PayQR всегда осуществляются с сохранением обратной совместимости.
 */